==> xcsoar-7.9.tar.xz: xcsoar-7.9/src/thread/RecursivelySuspensibleThread.hpp <==
/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2021 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#ifndef XCSOAR_THREAD_RECURSIVELY_SUSPENSIBLE_THREAD_HPP
#define XCSOAR_THREAD_RECURSIVELY_SUSPENSIBLE_THREAD_HPP

#include "SuspensibleThread.hpp"

/**
 * A version of SuspensibleThread that can be suspended recursively.
 * It will not be resumed until all calls to Suspend() have been
 * undone with as many calls to Resume().
 */
class RecursivelySuspensibleThread : public SuspensibleThread {
  /**
   * The thread should be suspended as long as this value is non-zero.
   * It is not protected the SuspensibleThread's mutex, because it may
   * only be accessed from one thread.
   */
  unsigned suspend_count;

public:
  RecursivelySuspensibleThread(const char *_name)
    :SuspensibleThread(_name) {}

  bool Start(bool suspended=false);

  void BeginSuspend();

  void Suspend();

  void Resume();
};

#endif

==> xcsoar-7.13.tar.xz: xcsoar-7.13/src/thread/RecursivelySuspensibleThread.hpp <==
/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2021 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#ifndef XCSOAR_THREAD_RECURSIVELY_SUSPENSIBLE_THREAD_HPP
#define XCSOAR_THREAD_RECURSIVELY_SUSPENSIBLE_THREAD_HPP

#include "SuspensibleThread.hpp"

/**
 * A version of SuspensibleThread that can be suspended recursively.
 * It will not be resumed until all calls to Suspend() have been
 * undone with as many calls to Resume().
 */
class RecursivelySuspensibleThread : public SuspensibleThread {
  /**
   * The thread should be suspended as long as this value is non-zero.
   * It is not protected the SuspensibleThread's mutex, because it may
   * only be accessed from one thread.
   */
  unsigned suspend_count;

public:
  RecursivelySuspensibleThread(const char *_name) noexcept
    :SuspensibleThread(_name) {}

  void Start(bool suspended=false);

  void BeginSuspend() noexcept;

  void Suspend() noexcept;

  void Resume() noexcept;
};

#endif
